Crate kcr_enterprisesearch_k8s_elastic_co

Crate kcr_enterprisesearch_k8s_elastic_co 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the enterprisesearch.k8s.elastic.co group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

enterprisesearch.k8s.elastic.co/v1

  • EnterpriseSearch

enterprisesearch.k8s.elastic.co/v1beta1

  • EnterpriseSearch

Modules

v1
v1beta1